@@ -162,7 +162,7 @@ def run_simulation(n_of_families = 250,
     if n_test < 0:
         print("Invalid number of test per day")
         sys.exit()
-    if not (policy_test == "Random" or policy_test == "Degree Centrality" or policy_test == "Betweenness Centrality" or "PBI"):
+    if policy_test not in ["Random", "Degree Centrality", "Betweenness Centrality", "PBI"]:
         print("Invalid test strategy")
         sys.exit()
     if contact_tracing_efficiency < 0 or contact_tracing_efficiency > 1:
