@@ -159,25 +159,25 @@ def generate_network(n_of_families, use_probabilities):
             node["pre_existing_conditions"] = np.random.choice(
                 [0, 1, 2, 3], p=[0.6, 0.2, 0.1, 0.1])
         
-        if node["age"] < 10:
+        if node["age"] == 0:
             node["death_rate"] = 0.002
-        elif node["age"] < 20:
+        elif node["age"] == 10:
             node["death_rate"] = 0.001
-        elif node["age"] < 30:
+        elif node["age"] == 20:
             node["death_rate"] = 0.001
-        elif node["age"] < 40:
+        elif node["age"] == 30:
             node["death_rate"] = 0.004
-        elif node["age"] < 50:
+        elif node["age"] == 40:
             node["death_rate"] = 0.009
-        elif node["age"] < 60:
+        elif node["age"] == 50:
             node["death_rate"] = 0.026
-        elif node["age"] < 70:
+        elif node["age"] == 60:
             node["death_rate"] = 0.10
-        elif node["age"] < 80:
+        elif node["age"] == 70:
             node["death_rate"] = 0.249
-        elif node["age"] < 90:
+        elif node["age"] == 80:
             node["death_rate"] = 0.308
-        elif node["age"] < 100:
+        elif node["age"] == 90:
             node["death_rate"] = 0.261
 
         node["agent_status"] = 'S'
